==> haskell-infer-license-0.2.0-352.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-6ceJ92eaiiG8vxZEAuvF8S
key:                  infer-license-0.2.0-6ceJ92eaiiG8vxZEAuvF8S
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  241d244bbe1ab47d2e26e063f84435b2
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-9.6.6/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/infer-license-0.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infer-license
hs-libraries:         HSinfer-license-0.2.0-6ceJ92eaiiG8vxZEAuvF8S
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 text-2.0.2
    text-metrics-0.3.3-EtdayY9JRqPIHrPm1Benmg

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-infer-license-0.2.0-353-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-6EhbsJpqErpF3cp3c1gxOw
key:                  infer-license-0.2.0-6EhbsJpqErpF3cp3c1gxOw
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  84e59a991b4de9763b7b32932b965d1a
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-9.6.6/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/infer-license-0.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infer-license
hs-libraries:         HSinfer-license-0.2.0-6EhbsJpqErpF3cp3c1gxOw
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 text-2.0.2
    text-metrics-0.3.3-542FvMYuyImLLT35eUtKmy

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
